package my.test;

import java.util.HashMap;

import org.springframework.beans.factory.BeanFactory;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

/**
 * A helper class to simplify interactions with Spring framework.
 */
public class SpringUtil {

	private static final String DEFAULT_CONTEXT = "DEFAULT_CONTEXT";
	private static final String[] DEFAULT_XML_PATH = { "spring.cfg.xml" };

	private static HashMap<String, ApplicationContext> appContextMap = new HashMap<String, ApplicationContext>();

	public static ApplicationContext getApplicationContext(
			String appContextLabel, String[] springXmls) {
		synchronized (appContextMap) {
			ApplicationContext applicationContext = appContextMap
					.get(appContextLabel);
			if (applicationContext == null) {
				applicationContext = new ClassPathXmlApplicationContext(
						springXmls);
				appContextMap.put(appContextLabel, applicationContext);
			}
			return applicationContext;
		}
	}

	public static ApplicationContext getDefaultApplicationContext() {
		return getApplicationContext(DEFAULT_CONTEXT, DEFAULT_XML_PATH);
	}

	public static ApplicationContext getApplicationContext(
			String appContextLabel) {
		ApplicationContext context = appContextMap.get(appContextLabel);
		if (context == null && DEFAULT_CONTEXT.equals(appContextLabel))
			context = getDefaultApplicationContext();
		return context;
	}

	public static <T> T getBean(String appContextLabel, String beanRefName,
			Class<T> beanClass) {
		return ((BeanFactory) getApplicationContext(appContextLabel)).getBean(
				beanRefName, beanClass);
	}

	public static Object getBean(String appContextLabel, String beanRefName) {
		return ((BeanFactory) getApplicationContext(appContextLabel))
				.getBean(beanRefName);
	}

	public static <T> T getBean(String name, Class<T> requiredType) {
		return getBean(DEFAULT_CONTEXT, name, requiredType);
	}

	public static Object getBean(String beanRefName) {
		return getBean(DEFAULT_CONTEXT, beanRefName);
	}

}
